/*  macro.h  */
#define	WordNumb	70
#define SentLen		600   //400
#define JSentLen	650   //420
#define WordLen		90    //45
#define JWordLen	50
#define ZokuLen		40
#define YakugoMax	8
#define YakMaxCt	7
#define MaxNr		2400  //2000

#define color_red	 printf("\33[31m");
#define color_light_blue printf("\33[36m");
#define color_yellow	 printf("\33[33m");
#define color_white	 printf("\33[m");
